searchData={"content_type":"text/markdown","items":[{"doc":"A fundamental HTTP client for interfacing directly with Supabase services.\n\n`Supabase.Fetcher` provides the groundwork for sending HTTP requests to the Supabase infrastructure. This includes utilities for various HTTP methods such as GET, POST, PUT, DELETE, and functions to simplify the process of streaming data or uploading files.","ref":"Supabase.Fetcher.html","title":"Supabase.Fetcher","type":"module"},{"doc":"- **Low-level HTTP Interactions**: This module allows for raw HTTP requests to any URL, simplifying interactions with web resources.\n- **Data Streaming**: Efficiently stream large data payloads, such as downloading files.\n- **Request Customization**: Extensive header customization and utility functions for constructing requests tailored to your requirements.\n- **Response Parsing**: Automatically converts JSON responses into Elixir maps and handles various response scenarios.","ref":"Supabase.Fetcher.html#module-key-features","title":"Key Features - Supabase.Fetcher","type":"module"},{"doc":"While `Supabase.Fetcher` is versatile and comprehensive, it operates at a very granular level. For most applications and needs, leveraging higher-level APIs that correspond to specific Supabase services is advisable:\n\n- [supabase-storage](https://github.com/zoedsoupe/supabase/tree/main/apps/supabase_storage)\n\nFor those seeking a more comprehensive integration with the entirety of Supabase's offerings, the [supabase-potion](https://github.com/zoedsoupe/supabase) package is available. This package provides an all-encompassing interface, streamlining your Supabase interactions.","ref":"Supabase.Fetcher.html#module-recommended-usage","title":"Recommended Usage - Supabase.Fetcher","type":"module"},{"doc":"If your aim is to directly harness this module as a low-level HTTP client, due to missing features in other packages or a desire to craft a unique Supabase integration, you can certainly do so. However, always keep in mind that `Supabase.Potion` and other Supabase-oriented packages might offer better abstractions and ease-of-use.\n\nUse `Supabase.Fetcher` with a clear understanding of its features and operations.","ref":"Supabase.Fetcher.html#module-disclaimer","title":"Disclaimer - Supabase.Fetcher","type":"module"},{"doc":"Convenience function that given a `apikey` and a optional ` token`, it will return the headers\nto be used in a request to your Supabase API.","ref":"Supabase.Fetcher.html#apply_headers/3","title":"Supabase.Fetcher.apply_headers/3","type":"function"},{"doc":"iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer apikey-value\"}]\n\n     iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\", \"token-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer token-value\"}]","ref":"Supabase.Fetcher.html#apply_headers/3-examples","title":"Examples - Supabase.Fetcher.apply_headers/3","type":"function"},{"doc":"Simple DELETE request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#delete/3","title":"Supabase.Fetcher.delete/3","type":"function"},{"doc":"iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}\n\n     iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:error, :not_found}","ref":"Supabase.Fetcher.html#delete/3-examples","title":"Examples - Supabase.Fetcher.delete/3","type":"function"},{"doc":"Simple GET request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#get/2","title":"Supabase.Fetcher.get/2","type":"function"},{"doc":"iex> Supabase.Fetcher.get(\"https://example.com\")\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#get/2-examples","title":"Examples - Supabase.Fetcher.get/2","type":"function"},{"doc":"","ref":"Supabase.Fetcher.html#get_full_url/2","title":"Supabase.Fetcher.get_full_url/2","type":"function"},{"doc":"Simple POST request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#post/3","title":"Supabase.Fetcher.post/3","type":"function"},{"doc":"iex> Supabase.Fetcher.post(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#post/3-examples","title":"Examples - Supabase.Fetcher.post/3","type":"function"},{"doc":"Simple PUT request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#put/3","title":"Supabase.Fetcher.put/3","type":"function"},{"doc":"iex> Supabase.Fetcher.put(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#put/3-examples","title":"Examples - Supabase.Fetcher.put/3","type":"function"},{"doc":"Makes a HTTP request to the desired URL, with default headers and\nstream back the response. Good to stream large files downlaods.\n\nYou can also pass custom `Finch` options directly to the underlying `Finch.stream/4` function.\nThose options can be seen on the [Finch documentation](https://hexdocs.pm/finch/Finch.html#stream/5-options).","ref":"Supabase.Fetcher.html#stream/3","title":"Supabase.Fetcher.stream/3","type":"function"},{"doc":"iex> {status, stream} = Supabase.Fetcher.stream(\"https://example.com\")\n     iex> file = File.stream!(\"path/to/file\", [], 4096)\n     Stream.run Stream.into(stream, file)","ref":"Supabase.Fetcher.html#stream/3-examples","title":"Examples - Supabase.Fetcher.stream/3","type":"function"},{"doc":"Upload a binary to the desired URL.\n\nparams:\n- `method`: `:put` or `:post`\n- `url`: the URL to upload the file\n- `file`: the path to the file to upload\n- `headers`: list of additional headers to append to the request","ref":"Supabase.Fetcher.html#upload/4","title":"Supabase.Fetcher.upload/4","type":"function"},{"doc":"iex> Supabase.Fetcher.upload(:post, \"https://example.com\", \"path/to/file\")\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#upload/4-examples","title":"Examples - Supabase.Fetcher.upload/4","type":"function"},{"doc":"","ref":"Supabase.Fetcher.html#version/0","title":"Supabase.Fetcher.version/0","type":"function"},{"doc":"Simple Supervisor to manage a Finch pool","ref":"Supabase.Fetcher.Application.html","title":"Supabase.Fetcher.Application","type":"module"},{"doc":"Defines Supabase HTTP Clients callbacks","ref":"Supabase.FetcherBehaviour.html","title":"Supabase.FetcherBehaviour","type":"behaviour"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#c:delete/3","title":"Supabase.FetcherBehaviour.delete/3","type":"callback"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#c:get/2","title":"Supabase.FetcherBehaviour.get/2","type":"callback"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#c:post/3","title":"Supabase.FetcherBehaviour.post/3","type":"callback"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#c:put/3","title":"Supabase.FetcherBehaviour.put/3","type":"callback"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#c:stream/3","title":"Supabase.FetcherBehaviour.stream/3","type":"callback"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#c:upload/4","title":"Supabase.FetcherBehaviour.upload/4","type":"callback"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#t:body/0","title":"Supabase.FetcherBehaviour.body/0","type":"type"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#t:headers/0","title":"Supabase.FetcherBehaviour.headers/0","type":"type"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#t:method/0","title":"Supabase.FetcherBehaviour.method/0","type":"type"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#t:reason/0","title":"Supabase.FetcherBehaviour.reason/0","type":"type"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#t:response/0","title":"Supabase.FetcherBehaviour.response/0","type":"type"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#t:result/0","title":"Supabase.FetcherBehaviour.result/0","type":"type"},{"doc":"","ref":"Supabase.FetcherBehaviour.html#t:url/0","title":"Supabase.FetcherBehaviour.url/0","type":"type"},{"doc":"# Supabase Fetcher\n\n![Supabase Logo](https://supabase.io/img/supabase-logo.svg)\n\nThe **Supabase Fetcher** is a versatile HTTP client that serves as an entry point for interacting with Supabase APIs from your Elixir applications. While it's often recommended to use higher-level APIs for specific Supabase services like [supabase-storage](https://github.com/zoedsoupe/supabase/tree/main/apps/supabase_storage) or the all-in-one package [supabase-potion](https://github.com/zoedsoupe/supabase), this SDK provides low-level capabilities for fine-grained control and customization.","ref":"readme.html","title":"Supabase Fetcher","type":"extras"},{"doc":"To get started with the Supabase Fetcher Elixir SDK, add it to your Elixir project's dependencies by including it in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:supabase_fetcher, \"~> 0.1\"}\n  ]\nend\n```\n\nAfter adding the dependency, run `mix deps.get` to fetch and install the SDK.","ref":"readme.html#installation","title":"Installation - Supabase Fetcher","type":"extras"},{"doc":"This SDK allows you to make HTTP requests to Supabase and handle responses efficiently. It comes with several functions for common HTTP operations, such as GET, POST, PUT, DELETE, and file uploads.","ref":"readme.html#overview","title":"Overview - Supabase Fetcher","type":"extras"},{"doc":"#","ref":"readme.html#usage","title":"Usage - Supabase Fetcher","type":"extras"},{"doc":"You can use `Supabase.Fetcher.stream/3` to make a GET request to a URL and stream back the response. This function is especially useful for streaming large file downloads. Custom `Finch` options can also be passed for more control over the request.\n\n```elixir\n{iex> {status, stream} = Supabase.Fetcher.stream(\"https://example.com\")\niex> file = File.stream!(\"path/to/file\", [], 4096)\nStream.run Stream.into(stream, file)\n```\n\n#","ref":"readme.html#streaming-large-files","title":"Streaming Large Files - Supabase Fetcher","type":"extras"},{"doc":"The SDK provides convenient functions for making common HTTP requests:\n\n- `Supabase.Fetcher.get/2`: Perform a GET request.\n- `Supabase.Fetcher.post/3`: Perform a POST request.\n- `Supabase.Fetcher.put/3`: Perform a PUT request.\n- `Supabase.Fetcher.delete/3`: Perform a DELETE request.\n\nThese functions format the response to a map or retrieve the error reason as a `String.t()`.\n\n#","ref":"readme.html#making-http-requests","title":"Making HTTP Requests - Supabase Fetcher","type":"extras"},{"doc":"You can use `Supabase.Fetcher.upload/4` to upload a binary file to a URL using either a POST or PUT request. This is useful for file uploads in your applications.\n\n```elixir\niex> Supabase.Fetcher.upload(:post, \"https://example.com/upload\", \"path/to/file\")\n```\n\n#","ref":"readme.html#uploading-files","title":"Uploading Files - Supabase Fetcher","type":"extras"},{"doc":"The SDK supports adding custom headers to requests. Additionally, you can use `Supabase.Fetcher.apply_headers/2` to conveniently set headers for authentication. It automatically includes the API key and, optionally, a token in the headers.\n\n```elixir\niex> headers = Supabase.Fetcher.apply_headers(\"apikey-value\")\niex> Supabase.Fetcher.get(\"https://example.com\", headers)\n```","ref":"readme.html#headers-and-authentication","title":"Headers and Authentication - Supabase Fetcher","type":"extras"},{"doc":"While the Supabase Fetcher Elixir SDK offers low-level control for making HTTP requests to Supabase, it is part of the broader Supabase ecosystem, which includes higher-level libraries for various Supabase services.","ref":"readme.html#acknowledgements","title":"Acknowledgements - Supabase Fetcher","type":"extras"},{"doc":"For more details on using this package, refer to the [Supabase Fetcher documentation](https://hexdocs.pm/supabase_fetcher).\n\n---\n\nWith the **Supabase Fetcher Elixir SDK**, you have the power to interact with Supabase APIs directly from your Elixir applications. Whether you need to stream large files, make custom HTTP requests, or upload files, this SDK has you covered. Enjoy the flexibility and control it offers in integrating with Supabase services! 😄","ref":"readme.html#additional-information","title":"Additional Information - Supabase Fetcher","type":"extras"}]}